#!/usr/bin/env python3
#
# MIT License
#
# Copyright (c) 2019 Andrea Bonomi <andrea.bonomi@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

TOKEN_COLUMNS = [
    "rowid",
    "type",
    "algo",
    "counter",
    "digits",
    "issuer_int",
    "issuer_ext",
    "label",
    "period",
    "exp_date",  # SecurID token
    "pin",  # SecurID token
    "serial",  # SecurID token
    "secret",
]
SQL_DROP_TABLE = "drop table token"
SQL_CREATE_TABLE = """
create table if not exists token (
    type text,
    algo text,
    counter integer,
    digits integer,
    issuer_int text,
    issuer_ext text,
    label text,
    period integer,
    exp_date date,
    pin date,
    serial text,
    secret text
)"""
SQL_INSERT = """
insert into token(type, algo, counter, digits, issuer_int, issuer_ext, label, period, exp_date, pin, serial, secret)
values(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
"""
SQL_DELETE = "delete from token where rowid=?"
SQL_SELECT_TOKENS = f"select {','.join(TOKEN_COLUMNS)} from token"



from freakotp.secret import Secret
from freakotp.token import Token, TokenType

RFC4226_TEST_VECTORS = """
   Count    Hexadecimal    Decimal        HOTP
   0        4c93cf18       1284755224     755224
   1        41397eea       1094287082     287082
   2         82fef30        137359152     359152
   3        66ef7655       1726969429     969429
   4        61c5938a       1640338314     338314
   5        33c083d4        868254676     254676
   6        7256c032       1918287922     287922
   7         4e5b397         82162583     162583
   8        2823443f        673399871     399871
   9        2679dc69        645520489     520489
"""
SECRET = "3132333435363738393031323334353637383930"


def test_rfc4226_test_vectors():
    tests = [x.strip() for x in RFC4226_TEST_VECTORS.split("\n")]
    tests = [x.split() for x in tests if x]
    tests = [(int(x[0]), x[3]) for x in tests if x[0] != "Count"]

    secret = Secret.from_hex(SECRET)
    token = Token(type=TokenType.HOTP, algorithm="SHA1", digits=6, secret=secret)
    for test in tests:
        assert token.calculate(counter=test[0]) == test[1]

    for test in tests:
        token = Token(type=TokenType.HOTP, algorithm="SHA1", digits=6, secret=secret, counter=test[0])
        assert token.calculate() == test[1]

    for test in tests:
        token = Token(type=TokenType.HOTP, algorithm="SHA1", digits=6, secret=secret)
        assert token.calculate(counter=test[0]) == test[1]



#!/usr/bin/env python3

from pathlib import Path
from setuptools import setup, find_packages
from freakotp.cli import __version__

requires = Path(__file__).parent / 'requirements.txt'
install_requires = [line.rstrip() for line in requires.read_text().split("\n") if line.strip()]

description = 'FreakOTP is a command line two-factor authentication application.'

setup(
    name='freakotp',
    version=__version__,
    description=description,
    long_description=description,
    url='https://github.com/andreax79/FreakOTP',
    author='Andrea Bonomi',
    author_email='andrea.bonomi@gmail.com',
    license='MIT',
    classifiers=[
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: Public Domain',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    zip_safe=True,
    include_package_data=True,
    packages=find_packages(exclude=['ez_setup', 'examples']),
    keywords='otp freeotp cli',
    py_modules=['freakotp'],
    install_requires=install_requires,
    entry_points={
        'console_scripts': [
            'freakotp=freakotp.cli:main',
        ],
    },
    test_suite='tests',
    tests_require=['pytest'],
)
